#!/bin/ksh
#############################################################################
# @copyright(external)
# Licensed Materials - Property of IBM
# 5724-R21
#
# (c) Copyright IBM Corp.  2008.   All Rights Reserved.
# US Government Users Restricted Rights
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corporation.
#
# IBM grants you ("Licensee") a non-exclusive, royalty free, license to use,
# copy and redistribute the Non-Sample Header file software in source and binary code form,
# provided that i) this copyright notice, license and disclaimer  appear on all copies of
# the software; and ii) Licensee does not utilize the software in a manner
# which is disparaging to IBM.
#
# This software is provided "AS IS."  IBM and its Suppliers and Licensors expressly disclaim all warranties, whether  EXPRESS OR IMPLIED,
# INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR WARRANTY OF  NON-INFRINGEMENT.  IBM AND ITS SUPPLIERS AND  LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE THAT RESULT FROM USE OR DISTRIBUTION OF THE SOFTWARE OR THE COMBINATION OF THE SOFTWARE WITH ANY OTHER CODE.  IN NO EVENT WILL IBM OR ITS SUPPLIERS  AND LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE SOFTWARE, EVEN IF IBM HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
#
# @endCopyright
#############################################################################


usage()
{
  $msgutil 410
  $msgutil 108
  $msgutil 109
}

err_message()
{
  $msgutil $*
  exit 1
}

#------------------------------------------------------------------------------
# config DB2 environment check
#

config_init_check()
{
  DB2INSTANCE_HOME=

  if [[ -z $DB2INSTANCE ]]; then
    err_message 412
  fi

  if [[ "$DB2INSTANCE" != "`whoami`" ]]; then
    err_message 377 $DB2INSTANCE
  fi

  DB2INSTANCE_HOME=`awk -F: '$1 ~ /^'"$DB2INSTANCE"'$/ {print $6}' /etc/passwd`

  if [[ ! -d $DB2INSTANCE_HOME/sqllib/db2tss/config ]]; then
    err_message 424 $DB2INSTANCE_HOME/sqllib/db2tss/config $DB2INSTANCE
  fi

  if [[ ! -w $DB2INSTANCE_HOME/sqllib/db2tss ]]; then
    err_message 414 `whoami` $DB2INSTANCE_HOME/sqllib/db2tss
  fi

  if [[ -z $DB2INSTALL_HOME ]]; then
    typeset line=`ls -la $DB2INSTANCE_HOME/sqllib | grep misc`
    DB2INSTALL_HOME=${line#*-\> }
    DB2INSTALL_HOME=${DB2INSTALL_HOME%\/misc}
    DB2INSTALL_HOME=${DB2INSTALL_HOME%\/misc/}
  fi

  if [[ ! -d $DB2INSTALL_HOME ]]; then
    err_message 415
  fi

  if [[ ! -d $DB2INSTALL_HOME/db2tss/stellent ]]; then
    err_message 413 $DB2INSTALL_HOME/db2tss/stellent
  fi

  if [[ ! -f $DB2INSTALL_HOME/db2tss/stellent/whitney_agntcfg.zip ]]; then
    err_message 423 $DB2INSTALL_HOME/db2tss/stellent/whitney_agntcfg.zip
  fi

  typeset status=`$DB2INSTANCE_HOME/sqllib/db2tss/bin/adminTool status -configPath $DB2INSTANCE_HOME/sqllib/db2tss/config 2>&1 | grep IQQD0055E`
  if [[ -z $status ]]; then
    err_message 416
  fi
}

#------------------------------------------------------------------------------
# setup DB2 environment setup
#

setup_init_check()
{
  if [[ ! -d $DB2INSTALL_HOME ]]; then
    err_message 415
  fi

  if [[ ! -d $DB2INSTALL_HOME/db2tss ]]; then
    err_message 413 $DB2INSTALL_HOME/db2tss
  fi

  if [[ ! -w $DB2INSTALL_HOME/db2tss ]]; then
    err_message 414 `whoami` $DB2INSTALL_HOME/db2tss
  fi
}

#------------------------------------------------------------------------------
# locate path to Stellent zip file given known zip file names
#

find_zipfiles()
{
  typeset hsxfile=$1

  $msgutil 107 $hsxfile 

  if [[ ! -d $SEARCH_TOP ]]; then
    err_message 417 $SEARCH_TOP
  fi

  HSXZIP=`find $SEARCH_TOP -name ''$hsxfile''`

  if [[ ! -f $HSXZIP ]]; then
    err_message 421 8.3.2 $hsxfile
  fi
}

#------------------------------------------------------------------------------
#  given a platform, prepare Stellent library (version 8.3.2) zip file names.
#
#  platform             Stellent                  
#  hardware             html/search export               
#  -------------------------------------------------------------
#  AIX 64bit            rtfilter_aix64_sx_hx_832.zip   
#  SunOS x86 64bit      rtfilter_sunamd64_sx_hx_832.zip   
#  SunOS SPARC          rtfilter_sun64_sx_hx_832.zip   
#  Linux 64bit          rtfilter_linuxx64_sx_hx_832.zip   
#  Linux 32bit          rtfilter_linuxia32_sx_hx_832.zip   
#  HP-UX IA64           rtfilter_hpipf64_sx_hx_832.zip   
#

locate_stellent_library()
{
  typeset UNAME=`uname`
  case $UNAME in
    AIX)
      find_zipfiles rtfilter_aix64_sx_hx_832.zip
      ;;
    SunOS)
      typeset UNAMEI=`uname -i`
      if [[ "$UNAMEI" = "i86pc" ]]; then
        find_zipfiles rtfilter_sunamd64_sx_hx_832.zip
      else
        find_zipfiles rtfilter_sun64_sx_hx_832.zip
      fi
      ;;
    Linux)
      if [[ "`which db2level`" = "" ]]; then
        $err_message 411
      fi
      typeset lvl=`db2level | grep DB21085I | grep "\"64\""`
      if [[ ! -z $lvl ]]; then
        # 64-bit library
        find_zipfiles rtfilter_linuxx64_sx_hx_832.zip
      else
        # 32-bit Stellent library for 32-bit DB2 instance on 64-bit Linux
        find_zipfiles rtfilter_linuxia32_sx_hx_832.zip
      fi
      ;;
    HP-UX)
      find_zipfiles rtfilter_hpipf64_sx_hx_832.zip
      ;;
  esac
}

setup_stellent_library()
{
  $msgutil 93 $DB2INSTANCE

  # prepare Stellent directory under db2ts directory of DB2 installation
  if [[ ! -d $DB2INSTALL_HOME/db2tss/stellent ]]; then
    $msgutil 104 $DB2INSTALL_HOME/db2tss/stellent
    mkdir $DB2INSTALL_HOME/db2tss/stellent
    chmod 755 $DB2INSTALL_HOME/db2tss/stellent
  fi

  $msgutil 105 $HSXZIP
  extract_stellent $HSXZIP $DB2INSTALL_HOME/db2tss/stellent

  if [[ ! -f $DB2INSTALL_HOME/db2tss/stellent/whitney_agntcfg.zip ]]; then
    err_message 423 $DB2INSTALL_HOME/db2tss/stellent/whitney_agntcfg.zip
  fi  

  cd $DB2INSTALL_HOME/db2tss; unzip -o $DB2INSTALL_HOME/db2tss/stellent/whitney_agntcfg.zip stellent\* > /dev/null 2>&1

  if [[ "$?" != "0" ]]; then
    err_message 418 $DB2INSTALL_HOME/db2tss/stellent/whitney_agntcfg.zip
  fi

  chmod 555 $DB2INSTALL_HOME/db2tss/stellent/*

  if [[ "$?" != "0" ]]; then
    err_message 425 $DB2INSTALL_HOME/db2tss/stellent
  fi
}

#------------------------------------------------------------------------------
# extract Stellent library files
#

extract_stellent()
{
  library=$1
  destination=$2
  typeset tmp_dir=$destination/tmp_dir

  if [[ ! -d $tmp_dir ]]; then
    mkdir -p $tmp_dir
  fi

  cd $tmp_dir; unzip $library >/dev/null 2>&1 ; cd ..

  if [[ "$?" != "0" ]]; then
    err_message 418 $library
  fi

  if [[ -z `find . -name "cmmap000.bin" -type f` ]]; then
    err_message 419 $destination/cmmap000.bin
  fi

  find . -name "*.a"      -type f -exec mv -f {} $destination >/dev/null 2>&1 \;
  find . -name "*.o"      -type f -exec mv -f {} $destination >/dev/null 2>&1 \;
  find . -name "*.so"     -type f -exec mv -f {} $destination >/dev/null 2>&1 \;
  find . -name "*.flt"    -type f -exec mv -f {} $destination >/dev/null 2>&1 \;
  find . -name "*.dat"    -type f -exec mv -f {} $destination >/dev/null 2>&1 \;
  find . -name "*.bin"    -type f -exec mv -f {} $destination >/dev/null 2>&1 \;
  find . -name "exsimple" -type f -exec mv -f {} $destination >/dev/null 2>&1 \;
  find . -name "*.zip"    -type f -exec mv -f {} $destination >/dev/null 2>&1 \;

  rm -rf $tmp_dir
}

#------------------------------------------------------------------------------
# sanity check several files in the Stellent directory
#

sanity_check_stellent_files()
{
  if [[ ! -f $DB2INSTALL_HOME/db2tss/stellent/cmmap000.bin ||
        ! -f $DB2INSTALL_HOME/db2tss/stellent/OutsideInProcess ||
        ! -f $DB2INSTALL_HOME/db2tss/stellent/htmlexport.cfg ||
        ! -f $DB2INSTALL_HOME/db2tss/stellent/searchexport.cfg ]]; then
    err_message 420 $DB2INSTALL_HOME/db2tss/stellent
  fi
}

#------------------------------------------------------------------------------
# modify omnifind configuration files to use with Stellent
#

enable_stellent()
{
  $msgutil 93 $DB2INSTANCE

  $msgutil 90 $DB2INSTALL_HOME/db2tss/stellent $DB2INSTANCE_HOME/sqllib/db2tss/stellent

  ln -fs $DB2INSTALL_HOME/db2tss/stellent  $DB2INSTANCE_HOME/sqllib/db2tss

  cd $DB2INSTANCE_HOME/sqllib/db2tss; unzip -o $DB2INSTALL_HOME/db2tss/stellent/whitney_agntcfg.zip config\* > /dev/null 2>&1

  if [[ "$?" != "0" ]]; then
    err_message 418 $DB2INSTALL_HOME/db2tss/stellent/whitney_agntcfg.zip
  fi

  # release.properties file should not contain keyword sutter_luw
  typeset tmp=`grep luw $DB2INSTANCE_HOME/sqllib/db2tss/config/releaseinfo/release.properties`
  if [[ ! -z $tmp ]]; then
    err_message 430 $DB2INSTANCE_HOME/sqllib/db2tss/config/releaseinfo/release.properties
  fi
}

#------------------------------------------------------------------------------
# restore omnifind default configuration files
#

disable_stellent()
{
  $msgutil 94 $DB2INSTANCE

  cp -f $DB2INSTALL_HOME/cfg/db2tss/config/defaults/parser_config.xml $DB2INSTANCE_HOME/sqllib/db2tss/config/defaults > /dev/null 2>&1

  if [[ "$?" != "0" ]]; then
    err_message 427 $DB2INSTALL_HOME/cfg/db2tss/config/defaults/parser_config.xml
  fi

  cp -f $DB2INSTALL_HOME/cfg/db2tss/config/releaseinfo/release.properties $DB2INSTANCE_HOME/sqllib/db2tss/config/releaseinfo > /dev/null 2>&1

  if [[ "$?" != "0" ]]; then
    err_message 427 $DB2INSTALL_HOME/cfg/db2tss/config/releaseinfo/release.properties
  fi

  # remove the Stellent soft link
  rm -rf $DB2INSTANCE_HOME/sqllib/db2tss/stellent

  # release.properties file should contain keyword sutter_luw
  typeset tmp=`grep luw $DB2INSTANCE_HOME/sqllib/db2tss/config/releaseinfo/release.properties`
  if [[ -z $tmp ]]; then
    err_message 430 $DB2INSTANCE_HOME/sqllib/db2tss/config/releaseinfo/release.properties
  fi
}


#------------------------------------------------------------------------------
# main
#

where_am_i=$(cd $(dirname $0) && pwd)
msgutil=${where_am_i}/../lib/ciemsg

if [[ ! -x $msgutil ]]; then
  print "Cannot execute message display utility $msgutil.  Check the file exists and you have execute permission to that file."

  exit 1
fi

if [ $# -lt 2 ]; then
  usage
  exit
fi

ACTION=$1
DB2INSTALL_HOME=$2
HSXZIP=


if [[ $ACTION = "setup" ]]; then
  if [ $# -lt 3 ]; then
    usage
    exit
  fi

  SEARCH_TOP=$3

  if [ ! -d $SEARCH_TOP ]; then
    usage
    exit
  fi

  setup_init_check
  locate_stellent_library
  setup_stellent_library
  sanity_check_stellent_files
  $DB2INSTALL_HOME/db2tss/lib/ciemsg 95

elif [[ $ACTION = "enable" ]]; then

  config_init_check
  sanity_check_stellent_files 
  enable_stellent
  $msgutil 91 $DB2INSTANCE

elif [[ $ACTION = "disable" ]]; then

  config_init_check
  disable_stellent
  $msgutil 92 $DB2INSTANCE

else

  usage

fi
