#!/bin/sh
#############################################################################
# @copyright(external)
# Licensed Materials - Property of IBM
# 5724-R21
#
# © Copyright IBM Corp.  2006.   All Rights Reserved. 
# US Government Users Restricted Rights 
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corporation.
#
# IBM grants you ("Licensee") a non-exclusive, royalty free, license to use,
# copy and redistribute the Non-Sample Header file software in source and binary code form,
# provided that i) this copyright notice, license and disclaimer  appear on all copies of
# the software; and ii) Licensee does not utilize the software in a manner
# which is disparaging to IBM.
#
# This software is provided "AS IS."  IBM and its Suppliers and Licensors expressly disclaim all warranties, whether  EXPRESS OR IMPLIED, 
# INCLUDING ANY IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR WARRANTY OF  NON-INFRINGEMENT.  IBM AND ITS SUPPLIERS AND  LICENSORS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE THAT RESULT FROM USE OR DISTRIBUTION OF THE SOFTWARE OR THE COMBINATION OF THE SOFTWARE WITH ANY OTHER CODE.  IN NO EVENT WILL IBM OR ITS SUPPLIERS  AND LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT, INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF OR INABILITY TO USE SOFTWARE, EVEN IF IBM HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
#
# @endCopyright  
#############################################################################

# startup script

#---------------------------------------------------------------------------
# Helper function to extract the heap size from config.xml
#---------------------------------------------------------------------------
getHeapSize() {
   r=$1
   TAG_VAL=startupHeapSize
   # The following command does the following extraction
   # 1. get the line containing heapSize tag from the config file 
   # 2. Remove leading spaces
   # 3. Remove leading tag
   # 4. Remove trailing tag to get the value
   temp=`cat $r | grep "<$TAG_VAL" | sed "s/^[[:space:]]*//" | sed "s+^.*<$TAG_VAL>++" | sed "s+</$TAG_VAL>.*$++"`
   if [ "$temp" != "" ]; then
      HEAP_SIZE=$temp
   fi
}

getIPv6() {
   r=$1
   IPv6=`grep "<IPv6>" $r | cut -d">" -f2 | cut -d"<" -f1 | tr TRUE true`
}

# TEMP1=`which "$0"`
TEMP1=`basename "$0"`
if [ ${TEMP1} = "${0}" ]; then
IFS=:
for dir in $PATH; do
if [ -x ${dir}/${TEMP1} ]; then
TEMP1=${dir}/${TEMP1}
break;
fi
done
else
TEMP1=${0}
fi

ARG0DIR=`dirname "$TEMP1"`
SETUP_PATH="${ARG0DIR}/setup.sh"
. "$SETUP_PATH"

# Change the current directory so that dumps will end up in the application directory
cd "${WHITNEY_HOME}"
CONFIG_XML=$WHITNEY_INSTANCE/config/config.xml
HEAP_SIZE=1500m

# Set Java to use logging properties
LOGGING_PATH=$WHITNEY_INSTANCE/config/ecmts_logging.properties
JVM_OPTIONS=-Djava.util.logging.config.file=$LOGGING_PATH

# Get the heap size from config.xml
getHeapSize $CONFIG_XML

# Get IPv6 flag
getIPv6 $CONFIG_XML
IPv6Flags=""  # default is IPv4
if [ "$IPv6" = "true" ]; then
   # set IPv6 flags to JVM
   IPv6Flags="-Djava.net.preferIPv4Stack=false -Djava.net.preferIPv6Addresses=true"
fi

# verify that file size is unlimited - fix bug 27891
fileSize=`ulimit -f`
if [ $fileSize != "unlimited" ]; then    
    ulimit -f unlimited
    fileSize=`ulimit -f`
    if [ $fileSize != "unlimited" ]; then
        echo "WARNING: The startup script was unable to set the file size parameter to unlimited. As a result, the indexing process might be slower."
	else
	    echo "WARNING: The file size was not set to unlimited as required. The startup script changed the value of the file size to unlimited."
    fi
fi

# verify that file number per process is unlimited or equal to  65536
nofile=`ulimit -n`
if [ $nofile != "unlimited" ] && [ $nofile != 65536 ]; then    	
	ulimit -n 65536
	nofile=`ulimit -n`
	if [ $nofile != 65536 ]; then
		echo "WARNING: The startup script was unable to set the number of files per process value to 65536. As a result, the indexing process might be slower."
	else
		echo "WARNING: The number of files per process value was not set to unlimited or to 65536 as required. The startup script changed this value to 65536."
	fi	
fi

"$JAVA_HOME/bin/java" -classpath "$CLASSPATH" com.ibm.es.nuvo.launcher.Launcher "$CONFIG_XML" $1 $2 $3 $4 $5 $6 $7 $8 $9 -Xmx$HEAP_SIZE $IPv6Flags "$JVM_OPTIONS"
