
------------------------------------------------------------------------
--  IBM  Licensed Materials - Property of IBM
--  5765-F41, 5724-B55, 5724-E49, 5724-S40, 5765-F35, 5724-N76             
--  (c) Copyright IBM Corporation 2007, 2008.                              
--  All rights reserved.                                                   
--
------------------------------------------------------------------------
--  Product Name: DB2 Text Search
--  Version:	9.5
-------------------------------------------------------------------------

--***********************************************************************
--***********************************************************************
--**
--**  File Name:         ciectbl.ddl
--**
--**  Description:       The following script is executed
--**                     when a database is enabled for text.
--**
--***********************************************************************
--***********************************************************************

--*---------------------------------------------------------------------
--* create administration table(s) per index (used for design documentation)
--*---------------------------------------------------------------------
-- CREATE TABLE
-- SYSIBMTS."TLOGTS123456"
--   (
--                                     -- operation code: 
--    "OPERATION"         INTEGER NOT NULL,
--                                     -- date-time of the log item:
--    "TIME"              TIMESTAMP NOT NULL,
--                                     -- primary key column 1:
--    "PK01"              <PrimaryKeyType>
--                                     -- primary key column n:
--    "PKnn"              <PrimaryKeyType>
--   )
--   PARTITIONING KEY (<subset of PK01,..,PKnn according to user table>);

------------------------------------------------------------------------

-- CREATE TABLE
-- SYSIBMTS."TEVENTTS123456"
--   (
--                                     -- operation code: 
--    "OPERATION"         INTEGER,
--                                     -- date-time of the event item:
--    "TIME"              TIMESTAMP,
--                                     -- severity class:
--    "SEVERITY"          INTEGER,
--                                     -- reason code:
--    "REASON"            INTEGER,
--                                     -- event message:
--    "MESSAGE"           VARCHAR(1024),
--                                     -- partition where the event occured:
--    "PARTITION"         INTEGER,
--                                     -- primary key:
--    "PK01"              <PrimaryKeyType>
--                                     -- primary key column 14:
--    "PKnn"              <PrimaryKeyType>
--   )
--   PARTITIONING KEY (<subset of PK01,..,PKnn according to user table>);
--
--*---------------------------------------------------------------------
--* create administration table(s)
--*---------------------------------------------------------------------
CREATE TABLE
SYSIBMTS."SYSTSDEFAULTS"
     (
--                                     -- name of the default item:
      "NAME"              VARCHAR(30)               NOT NULL,
--                                     -- (constraint "DbDefaultsIx0" unique)
--                                     -- value of the default item:
      "VALUE"             VARCHAR(512)              NOT NULL,
--                                     -- attribute of the item:
--                                     -- <value > 0 ==> item is part of the view>
      "TYPE"              INTEGER                   NOT NULL
                                                    WITH DEFAULT 1
     );

------------------------------------------------------------------------

CREATE TABLE
SYSIBMTS."SYSTSINDEXES"
     (
--                                     -- identifier of the text index:
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- name of the text index:
      "INDEXSCHEMA"       VARCHAR(128)              NOT NULL,
--                                     -- schema of the text index:
      "INDEXNAME"         VARCHAR(128)              NOT NULL,
--                                     -- optional directory of the Find-It collection:
      "COLLECTIONDIRECTORY"
                          VARCHAR(512), 
--                                     -- mising part: partitionnumber 
      "COLLECTIONNAMEPREFIX"
                          VARCHAR(128)              NOT NULL,
--                                     -- maximum length of the key in user table
      "MAXIMUMKEYLENGTH"  INTEGER                   NOT NULL,
--                                     -- schema of the index log table:
      "LOGTABLESCHEMA"    VARCHAR(128),
--                                     -- name of the text index log table:
      "LOGTABLENAME"      VARCHAR(128),
--                                     -- schema of the text index log view:
      "LOGVIEWSCHEMA"     VARCHAR(128),
--                                     -- name of the text index log view:
      "LOGVIEWNAME"       VARCHAR(128),
--                                     -- schema of the text index event table:
      "EVENTTABLESCHEMA"  VARCHAR(128)              NOT NULL,
--                                     -- name of the text index event table:
      "EVENTTABLENAME"    VARCHAR(128)              NOT NULL,
--                                     -- schema of the text index event view:
      "EVENTVIEWSCHEMA"   VARCHAR(128)              NOT NULL,
--                                     -- name of the text index event view:
      "EVENTVIEWNAME"     VARCHAR(128)              NOT NULL,
--                                     -- minimum change(s) for automatic update:
      "UPDATEMINIMUM"     INTEGER,
--                                     -- update frequency information:
      "UPDATEFREQUENCY"   VARCHAR(300)              NOT NULL,
--                                     -- mode for update index:
--                                     -- <0 ==> initial update to be done>
--                                     -- <1 ==> incremental update to be done>
      "UPDATEMODE"        INTEGER                   NOT NULL,
--                                     -- mode for reorganization of index:
--                                     -- <0 ==> automatic
--                                     -- <1 ==> manual
      "REORGANIZATIONMODE" INTEGER,
--                                     -- index configuration signature:
--                                     -- time index was created:
      "CREATIONTIME"      TIMESTAMP                 NOT NULL 
                                                    WITH DEFAULT CURRENT TIMESTAMP,
--                                     -- time index was last updated:
      "UPDATETIME"        TIMESTAMP                 NOT NULL 
                                                    WITH DEFAULT CURRENT TIMESTAMP,
--                                     -- expressionlists in format:       
--                                     -- A0'0attributesA0'1
--                                     -- U0'0userexitcolumnsU0'1
--                                     -- V0'0viewkeycolumnsV0'1
      "EXPRESSIONLISTS"   CLOB(32K)                 NOT NULL,
--                                     -- number of expressions in each list
--                                     -- of EXPRESSIONLISTS in format:       
--                                     -- number of attributes (2 Bytes) 
--                                     -- number of results (2 Bytes)
--                                     -- number of sortorder expr. (2 Bytes)
--                                     -- number of view key columns (2 Bytes)
--                                     -- high-order byte of INTEGERs first !
      "EXPRESSIONNUMBERS" VARCHAR(32) FOR BIT DATA  NOT NULL,
--                                     -- indicates if index is cacheable:
--                                     -- <0 ==> not cacheable
--                                     -- <1 ==> cacheable

--                                     --  local schema of capture control tables
--                                     --  for replication:
      "LOCALCONTROLSCHEMA" VARCHAR(128),
--                                     -- 
      "USEREXITFUNCTION"  VARCHAR(18),
      "USEREXITLIBRARY"   VARCHAR(256),

      CONSTRAINT "SYSTSINDEXESIX0"
      PRIMARY KEY ("INDEXIDENTIFIER")
--    CONSTRAINT "SYSTSINDEXESIX1"
--    UNIQUE ("INDEXSCHEMA","INDEXNAME")
     );

------------------------------------------------------------------------

CREATE TABLE
SYSIBMTS."SYSTSCOLUMNS"
     (
--                                     -- identifier of the text index:
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- schema of the text table:
--                                        (base, nickname or view)
      "TABLESCHEMA"       VARCHAR(128)              NOT NULL,
--                                     -- name of the text table:
--                                        (base, nickname or view)
      "TABLENAME"         VARCHAR(128)              NOT NULL,
--                                     -- schema of the alias:
--                                        (equal to tableschema for
--                                         base table, nickname, view)
      "ALIASSCHEMA"       VARCHAR(128)              NOT NULL,
--                                     -- name of the alias:
--                                        (equal to tablesname for
--                                         base table, nickname, view)
      "ALIASNAME"         VARCHAR(128)              NOT NULL,
--                                     -- type of the text table:
--                                     -- <T ==> regular table
--                                     -- <N ==> nickname table
--                                     -- <V ==> view
      "TABLETYPE"         CHAR(1)                   NOT NULL,
--                                     -- name of the text column:
      "COLUMNNAME"        VARCHAR(128)              NOT NULL,
--                                     -- indicates if index is used by DB2
--                                     -- <0 ==> not used by rewriter
--                                     -- <1 ==> used by rewriter
--                                     -- <2 ==> marked invalid
      "ACTIVEFLAG"        INTEGER                   NOT NULL,
--                                     -- schema of the type transformation function:
      "FUNCTIONSCHEMA"    VARCHAR(128),
--                                     -- name of the type transformation function:
      "FUNCTIONNAME"      VARCHAR(18),
--                                     -- text information:
      "CODEPAGE"          INTEGER                   NOT NULL,
      "LANGUAGE"          VARCHAR(5)                NOT NULL,
      "FORMAT"            INTEGER                   NOT NULL,
--                                     -- redundant index properties from TextIndexes:
--                                     -- IndexDirectory WorkDirectory MaximumPrimaryKey
--                                     -- PreferredNode NumberOfNodes
--                                     -- each "string" value preceeded by two bytes length
      "INDEXPROPERTIES"   VARCHAR(1024) FOR BIT DATA NOT NULL
     )
     PARTITIONING KEY ("TABLESCHEMA","TABLENAME","COLUMNNAME");

------------------------------------------------------------------------

CREATE INDEX
SYSIBMTS."SYSTSCOLUMNSIX1" ON SYSIBMTS."SYSTSCOLUMNS"
     ("INDEXIDENTIFIER"  ASC);
CREATE INDEX
SYSIBMTS."SYSTSCOLUMNSIX2" ON SYSIBMTS."SYSTSCOLUMNS"
     ("TABLESCHEMA","TABLENAME","COLUMNNAME"  ASC);

------------------------------------------------------------------------

CREATE TABLE
SYSIBMTS."SYSTSFORMATS"
     (
--                                     -- identifier of the text document format:
--                                        for logical foreign key ref from ttextcolumns
      "FORMATIDENTIFIER"  INTEGER                     NOT NULL,
--                                     -- (constraint "FormatsIx0" unique)
--                                     -- name of the text document format:
      "FORMATNAME"        VARCHAR(30)                 NOT NULL,
--                                     -- (constraint "FormatsIx1" unique)
--                                     -- content mime type
      "MIMETYPE"          VARCHAR(256)                NOT NULL
     );

------------------------------------------------------------------------

CREATE TABLE
SYSIBMTS."SYSTSMODELS"
     (
--                                     -- identifier of the text index:
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- name of the document format:
      "FORMATNAME"        VARCHAR(30)               NOT NULL,
--                                     -- path-name of model file:
      "MODELFILE"         VARCHAR(256)              NOT NULL,
--                                     --
      CONSTRAINT "SYSTSMODELSIX0"
      PRIMARY KEY ("FORMATNAME","INDEXIDENTIFIER"),
      CONSTRAINT "SYSTSMODELSFK0"
      FOREIGN KEY ("INDEXIDENTIFIER")
      REFERENCES SYSIBMTS."SYSTSINDEXES" ON DELETE CASCADE
     );

------------------------------------------------------------------------

CREATE TABLE
SYSIBMTS."SYSTSLOCKS"
     (
--                                     -- identifier for the command:
--                                     -- DISABLE (2), CREATE (7), 
--                                     -- DROP (8), UPDATE (9),
--                                     -- ALTER (11), CLEAR (12) 
      "COMMANDIDENTIFIER" INTEGER                   NOT NULL,
--                                     -- identifier of the text index:
--                                        if lockscope == 0
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- scope of the lock:
--                                     -- INDEX(0), DATABASE(1)
      "LOCKSCOPE"         INTEGER                   NOT NULL,
--                                     -- process identifier of requestor:
      "PROCESSIDENTIFIER" INTEGER                   NOT NULL,
--                                     -- thread identifier of requestor:
      "THREADIDENTIFIER"  INTEGER                   NOT NULL,
--                                     -- partition the requestor was running on:
      "PARTITION"         INTEGER                   NOT NULL,
--                                     -- time the lock was requested:
      "LOCKTIME"          TIMESTAMP                 NOT NULL,
--                                     --
      CONSTRAINT "SYSTSLOCKSIX0"
      PRIMARY KEY ("LOCKSCOPE", "INDEXIDENTIFIER")
     );

------------------------------------------------------------------------

CREATE TABLE
SYSIBMTS."SYSTSCONFIGURATION"
     (
--                                     -- identifier of the text index:
      "INDEXIDENTIFIER"   VARCHAR(18)               NOT NULL,
--                                     -- configuration parameter name:
      "PARAMETER"         VARCHAR(30)               NOT NULL,
--                                     -- configuration parameter value:
      "VALUE"             VARCHAR(512)              NOT NULL,
--
      CONSTRAINT "SYSTSCONFIGURATIONFK0"
      FOREIGN KEY ("INDEXIDENTIFIER")
      REFERENCES SYSIBMTS."SYSTSINDEXES" ON DELETE CASCADE
     );

------------------------------------------------------------------------

CREATE INDEX
SYSIBMTS."SYSTSCONFIGURATIONIX1" ON SYSIBMTS."SYSTSCONFIGURATION"
     ("INDEXIDENTIFIER"  ASC);

------------------------------------------------------------------------

CREATE TABLE
SYSIBMTS."SYSTSREPLICATION"
     (
--                                        -- identifier of the text index:
      "INDEXIDENTIFIER"         VARCHAR(18)         NOT NULL,
--                                        -- remote schema of source table:
      "REMOTESOURCETABLESCHEMA" VARCHAR(128)        NOT NULL,
--                                        -- name of remote source table:
      "REMOTESOURCETABLENAME"   VARCHAR(128)        NOT NULL,
--                                        -- remote schema of capture table:
      "REMOTECAPTABLESCHEMA"    VARCHAR(128)        NOT NULL,
--                                        -- name of remote capture table:
      "REMOTECAPTABLENAME"      VARCHAR(128)        NOT NULL,
--                                        -- name of federated server:
      "SERVERNAME"              VARCHAR(128)        NOT NULL,
--                                        -- type of federated server:
      "SERVERTYPE"              VARCHAR(30)         NOT NULL,
--                                        -- version of federated server:
      "SERVERVERSION"           VARCHAR(18)         NOT NULL,
--                                        -- 
      CONSTRAINT "SYSTSREPLICATIONIX0"
      FOREIGN KEY ("INDEXIDENTIFIER")
      REFERENCES SYSIBMTS."SYSTSINDEXES" ON DELETE CASCADE
     );

------------------------------------------------------------------------

--*---------------------------------------------------------------------
--* grant privilege(s) on administration table(s)
--*---------------------------------------------------------------------
GRANT SELECT ON TABLE  SYSIBMTS."SYSTSDEFAULTS"        TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS."SYSTSINDEXES"         TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS."SYSTSCOLUMNS"         TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS."SYSTSFORMATS"         TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS."SYSTSMODELS"          TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS."SYSTSLOCKS"    TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS."SYSTSCONFIGURATION"   TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS."SYSTSREPLICATION" TO PUBLIC;

------------------------------------------------------------------------

