
------------------------------------------------------------------------
--  IBM  Licensed Materials - Property of IBM
--  5765-F41, 5724-B55, 5724-E49, 5724-S40, 5765-F35, 5724-N76             
--  (c) Copyright IBM Corporation 2007, 2008.                              
--  All rights reserved.                                                   
--
------------------------------------------------------------------------
--  Product Name: DB2 Text Search
--  Version:	9.5
-------------------------------------------------------------------------

--***********************************************************************
--***********************************************************************
--**
--**  File Name:         ciecview.ddl     
--**
--**  Description:       The following script is executed
--**                     when a database is enabled for text.
--**
--***********************************************************************
--***********************************************************************

--*---------------------------------------------------------------------
--* create administration view(s) per index (sample)
--*---------------------------------------------------------------------
-- CREATE VIEW
-- SYSIBMTS.EVENTTS123456
--   ( PK01,
--     OPERATION,
--     TIME,
--     REASON,
--     MESSAGE
--   )
-- AS
--    SELECT  "PK01",
--            "OPERATION",
--            "TIME",
--            "SEVERITY",
--            "REASON",
--            "MESSAGE"
--    FROM  SYSIBMTS."TEVENTTS123456";
--
--*---------------------------------------------------------------------
--* create the administration view(s)
--*---------------------------------------------------------------------
CREATE VIEW SYSIBMTS.TSDEFAULTS
       ( DEFAULTNAME,
         DEFAULTVALUE
       )
   AS
      SELECT  "NAME",
              "VALUE"
      FROM  SYSIBMTS."SYSTSDEFAULTS" WHERE "TYPE" > 0;

------------------------------------------------------------------------
------------------------------------------------------------------------               

CREATE VIEW SYSIBMTS.TSINDEXES
       ( INDSCHEMA,
         INDNAME,
         TABSCHEMA, 
         TABNAME,
         COLNAME, 
         CODEPAGE, 
         LANGUAGE, 
         FORMAT,
         FUNCTIONSCHEMA,
         FUNCTIONNAME,
         COLLECTIONDIRECTORY, 
         UPDATEFREQUENCY, 
         UPDATEMINIMUM,
         EVENTVIEWSCHEMA,
         EVENTVIEWNAME,
         STAGINGVIEWSCHEMA, 
         STAGINGVIEWNAME,
         REORGAUTOMATIC,
         RECREATEONUPDATE,
         ATTRIBUTES,
         COLLECTIONNAMEPREFIX,
         COMMENT
       )

 AS SELECT TI."INDEXSCHEMA",
           TI."INDEXNAME",
           TC."ALIASSCHEMA",
           TC."ALIASNAME",
           TC."COLUMNNAME",
           TC."CODEPAGE",
           TC."LANGUAGE",
           (SELECT TF."FORMATNAME" FROM SYSIBMTS.SYSTSFORMATS TF
                  WHERE TC."FORMAT" = TF."FORMATIDENTIFIER"),
           TC."FUNCTIONSCHEMA",
           TC."FUNCTIONNAME",
           TI."COLLECTIONDIRECTORY",
           TI."UPDATEFREQUENCY",
           TI."UPDATEMINIMUM",
           TI."EVENTVIEWSCHEMA",
           TI."EVENTVIEWNAME",
           TI."LOGVIEWSCHEMA",
           TI."LOGVIEWNAME",
           TI."REORGANIZATIONMODE",
           CASE WHEN TI."LOGVIEWNAME" IS NULL THEN 1 ELSE 0 END,
           SYSIBMINTERNAL.SYSTS_ATTRIBUTES_EXPR("EXPRESSIONLISTS"),
           TI.COLLECTIONNAMEPREFIX,
           (SELECT TC."VALUE" FROM SYSIBMTS.SYSTSCONFIGURATION TC
                  WHERE TC."INDEXIDENTIFIER" = TI."INDEXIDENTIFIER" AND
                        TC."PARAMETER" = 'COMMENT')

      FROM  SYSIBMTS."SYSTSCOLUMNS"  TC,
            SYSIBMTS."SYSTSINDEXES"  TI
      WHERE TC."INDEXIDENTIFIER" = TI."INDEXIDENTIFIER"
;

--------------------------------------------------------------------------------

CREATE VIEW SYSIBMTS.TSCONFIGURATION
       ( INDSCHEMA,
         INDNAME,  
         PARAMETER,
         VALUE
       ) AS 
      SELECT TI."INDEXSCHEMA",
             TI."INDEXNAME",
             TC."PARAMETER",
             TC."VALUE"
      FROM  SYSIBMTS."SYSTSCONFIGURATION" TC,
            SYSIBMTS."SYSTSINDEXES"   TI
      WHERE TC."INDEXIDENTIFIER" = TI."INDEXIDENTIFIER"    
            AND NOT EXISTS 
                (SELECT * 
                 FROM SYSIBMTS.SYSTSDEFAULTS AS TD 
                 WHERE TC.PARAMETER = TD.NAME AND TD.TYPE = 0)
;

--------------------------------------------------------------------------------

CREATE VIEW SYSIBMTS.TSLOCKS
       ( COMMAND,
         LOCKSCOPE,
         INDSCHEMA,
         INDNAME,  
         PROCESSID,
         THREADID,
         LOCKCREATETIME
       )
        AS SELECT CASE WHEN CL."COMMANDIDENTIFIER" = 1
                       THEN CAST ('ENABLE DATABASE' AS VARCHAR(30))
	               WHEN CL."COMMANDIDENTIFIER" = 2
                       THEN CAST ('DISABLE DATABASE' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 7
                       THEN CAST ('CREATE INDEX' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 8
                       THEN CAST ('DROP INDEX' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 9
                       THEN CAST ('UPDATE INDEX' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 11
                       THEN CAST ('ALTER INDEX' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 12
                       THEN CAST ('CLEAR EVENTS' AS VARCHAR(30))
                       ELSE CAST (DIGITS(CL."COMMANDIDENTIFIER") AS VARCHAR(30))
                  END,
                  CASE WHEN CL."LOCKSCOPE" = 0
                       THEN CAST ('INDEX' AS VARCHAR(30))
                       WHEN CL."LOCKSCOPE" = 1
                       THEN CAST ('DATABASE' AS VARCHAR(30))
                       ELSE CAST (DIGITS(CL."LOCKSCOPE") AS VARCHAR(30))
                  END,
                  TI."INDEXSCHEMA",
                  TI."INDEXNAME",
                  CL."PROCESSIDENTIFIER",
                  CL."THREADIDENTIFIER",
                  CL."LOCKTIME"
        FROM  SYSIBMTS."SYSTSLOCKS"  CL,
              SYSIBMTS."SYSTSINDEXES"  TI
        WHERE CL."INDEXIDENTIFIER" = TI."INDEXIDENTIFIER"

        UNION ALL

           SELECT CASE WHEN CL."COMMANDIDENTIFIER" = 1
                       THEN CAST ('ENABLE DATABASE' AS VARCHAR(30))
	               WHEN CL."COMMANDIDENTIFIER" = 2
                       THEN CAST ('DISABLE DATABASE' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 7
                       THEN CAST ('CREATE INDEX' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 8
                       THEN CAST ('DROP INDEX' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 9
                       THEN CAST ('UPDATE INDEX' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 11
                       THEN CAST ('ALTER INDEX' AS VARCHAR(30))
                       WHEN CL."COMMANDIDENTIFIER" = 12
                       THEN CAST ('CLEAR EVENTS' AS VARCHAR(30))
                       ELSE CAST (DIGITS(CL."COMMANDIDENTIFIER") AS VARCHAR(30))
                  END,
                  CASE WHEN CL."LOCKSCOPE" = 0
                       THEN CAST ('INDEX' AS VARCHAR(30))
                       WHEN CL."LOCKSCOPE" = 1
                       THEN CAST ('DATABASE' AS VARCHAR(30))
                       ELSE CAST (DIGITS(CL."LOCKSCOPE") AS VARCHAR(30))
                  END,
                  CAST (NULL AS VARCHAR(128)),
                  CAST (NULL AS VARCHAR(128)),
                  CL."PROCESSIDENTIFIER",
                  CL."THREADIDENTIFIER",
                  CL."LOCKTIME"
        FROM  SYSIBMTS."SYSTSLOCKS"  CL
        WHERE NOT EXISTS(SELECT 1 FROM SYSIBMTS."SYSTSINDEXES"  TI
                         WHERE TI."INDEXIDENTIFIER" = CL."INDEXIDENTIFIER"
                        )
;

--------------------------------------------------------------------------------

CREATE VIEW SYSIBMTS.TSCOLLECTIONNAMES
       ( INDSCHEMA,
         INDNAME,  
         COLLECTIONNAME
       )
	AS SELECT TI.INDEXSCHEMA,
             TI.INDEXNAME,
--  DBPARTITIONNUM has to be padded left with zeroes:
             TI.COLLECTIONNAMEPREFIX || SUBSTR(VARCHAR(DECIMAL(P.DBPARTITIONNUM/10000.0,4,4)),2,4)
      FROM SYSIBMTS.SYSTSINDEXES TI,
           SYSIBMTS.SYSTSCOLUMNS TC,
           SYSCAT.TABLES T,
           SYSCAT.TABLESPACES TS,
           SYSCAT.DBPARTITIONGROUPDEF P
      WHERE TI.INDEXIDENTIFIER = TC.INDEXIDENTIFIER AND
            TC.TABLESCHEMA = T.TABSCHEMA AND
            TC.TABLENAME = T.TABNAME AND
            T.TBSPACEID = TS.TBSPACEID AND
            TS.DBPGNAME = P.DBPGNAME;

--*---------------------------------------------------------------------
--* grant privilege(s) on the administration view(s) to public
--*---------------------------------------------------------------------
GRANT SELECT ON TABLE  SYSIBMTS.TSDEFAULTS         TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS.TSINDEXES          TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS.TSCONFIGURATION    TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS.TSLOCKS            TO PUBLIC;
GRANT SELECT ON TABLE  SYSIBMTS.TSCOLLECTIONNAMES  TO PUBLIC;

------------------------------------------------------------------------

